@@ -36,4 +36,8 @@ pub enum ErrorCode {
     OutstandingTokens,
     #[msg("Invalid freeze authority")]
     InvalidFreezeAuthority,
+    #[msg("Invalid claim receipt")]
+    InvalidClaimReceipt,
+    #[msg("Public key mismatch")]
+    PublicKeyMismatch,
 }
\ No newline at end of file
