@@ -4,7 +4,7 @@ use {
 };
 
 #[derive(Accounts)]
-#[instruction(bump: u8, target: Pubkey)]
+#[instruction(target: Pubkey)]
 pub struct CreateClaimReceiptCtx<'info> {
     token_manager: Box<Account<'info, TokenManager>>,
 
@@ -18,7 +18,7 @@ pub struct CreateClaimReceiptCtx<'info> {
     #[account(
         init,
         payer = payer,
-        seeds = [CLAIM_RECEIPT_SEED.as_bytes(), token_manager.key().as_ref(), target.key().as_ref()], bump = bump,
+        seeds = [CLAIM_RECEIPT_SEED.as_bytes(), token_manager.key().as_ref(), target.as_ref()], bump,
         space = CLAIM_RECEIPT_SIZE,
     )]
     claim_receipt: Box<Account<'info, ClaimReceipt>>,
@@ -27,6 +27,6 @@ pub struct CreateClaimReceiptCtx<'info> {
     system_program: Program<'info, System>,
 }
 
-pub fn handler(_ctx: Context<CreateClaimReceiptCtx>, _bump: u8, _target: Pubkey) -> ProgramResult {
+pub fn handler(_ctx: Context<CreateClaimReceiptCtx>, _target: Pubkey) -> ProgramResult {
     return Ok(())
 }
\ No newline at end of file
